.. _large_deformation-hyperelastic_ul_up:

large_deformation/hyperelastic_ul_up.py
=======================================

**Description**


Compressible Mooney-Rivlin hyperelastic material model.

Large deformation is described using the updated Lagrangian formulation.
Incompressibility is treated by mixed displacement-pressure formulation.
Models of this kind can be used to model e.g. rubber or some biological
materials.


.. image:: /../doc/images/gallery/large_deformation-hyperelastic_ul_up.png


:download:`source code </../sfepy/examples/large_deformation/hyperelastic_ul_up.py>`

.. literalinclude:: /../sfepy/examples/large_deformation/hyperelastic_ul_up.py

